# FieldReport

Field report commands are used to write a field output report and free body computational results to an ASCII file.

## Create field reports in Session

```{eval-rst}
.. autoclass:: abaqus.FieldReport.FieldReportSession.FieldReportSession
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

```

## Classes

### FieldReportOptions

```{eval-rst}
.. autoclass:: abaqus.FieldReport.FieldReportOptions.FieldReportOptions
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### FreeBodyReportOptions

```{eval-rst}
.. autoclass:: abaqus.FieldReport.FreeBodyReportOptions.FreeBodyReportOptions
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### OdbFieldVarList

```{eval-rst}
.. autoclass:: abaqus.FieldReport.OdbFieldVarList.OdbFieldVarList
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### OdbModelFieldVarList

```{eval-rst}
.. autoclass:: abaqus.FieldReport.OdbModelFieldVarList.OdbModelFieldVarList
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### writeFieldReport

```{eval-rst}
.. automodule:: abaqus.FieldReport.writeFieldReport
    :members:
    :special-members: __init__
    :show-inheritance:
```

### writeFreeBodyReport

```{eval-rst}
.. automodule:: abaqus.FieldReport.writeFreeBodyReport
    :members:
    :special-members: __init__
    :show-inheritance:
```
